@@ -10,6 +10,7 @@ from simpel_pages.models import Category, Tag
 from simpel_pages.settings import pages_settings
 
 from .helpers import log_visitor
+from .models import RootPage
 
 
 @csrf_protect
@@ -20,7 +21,8 @@ def serve_page(request, path):
         raise Http404
 
     path_components = [component for component in path.split("/") if component]
-    page, args, kwargs = site.rootpage.page.specific.route(request, path_components)
+    site_root = RootPage.objects.get(site=site)
+    page, args, kwargs = site_root.page.specific.route(request, path_components)
 
     for fn in hookup.get_hooks("PAGES_BEFORE_SERVE"):
         result = fn(page, request, args, kwargs)
@@ -36,12 +38,13 @@ def serve_page(request, path):
 def serve_category(request, slug):
     category = get_object_or_404(Category, slug=slug)
     site = get_current_site(request)
+    site_root = RootPage.objects.get(site=site)
     real_model = request.GET.get("type", None)
     filters = dict()
     if real_model is not None:
         filters["real_model"] = real_model
     filters["category__slug__in"] = [category.slug]
-    queryset = site.rootpage.page.get_descendants().filter(**filters).live()
+    queryset = site_root.page.get_descendants().filter(**filters).live()
     log_visitor(request, content=category)
     return ListView.as_view(
         queryset=queryset,
@@ -55,12 +58,13 @@ def serve_category(request, slug):
 def serve_tag(request, slug):
     tag = get_object_or_404(Tag, slug=slug)
     site = get_current_site(request)
+    site_root = RootPage.objects.get(site=site)
     real_model = request.GET.get("type", None)
     filters = dict()
     if real_model is not None:
         filters["real_model"] = real_model
     filters["tags__slug__in"] = [tag.slug]
-    queryset = site.rootpage.page.get_descendants().filter(**filters).live()
+    queryset = site_root.page.get_descendants().filter(**filters).live()
     log_visitor(request, content=tag)
     return ListView.as_view(
         queryset=queryset,
